@@ -41,7 +41,7 @@ class Easyocrpipleline:
             dictionary[result[i][1]]["score"] = result[i][2]
         json_name = file.split('/')[-1].split('.')[0]
         # json log file create
-        with open("log/"+json_name+".json", "w") as outfile:
+        with open("/tmp"+json_name+".json", "w") as outfile:
             json.dump(dictionary, outfile)
 
     def image_process(self, path):
